@@ -12,6 +12,7 @@ const bool Preferences::BADGE3DSTYLE;
 const bool Preferences::LAYOUTSINFORMATIONWINDOW;
 const bool Preferences::AUTOSTART;
 const bool Preferences::BORDERLESSMAXIMIZED;
+const bool Preferences::ISAVAILABLEGEOMETRYBROADCASTEDTOPLASMA;
 const bool Preferences::METAPRESSFORAPPLAUNCHER;
 const bool Preferences::METAHOLDFORBADGES;
 const int Preferences::SCREENSDELAY;
@@ -27,6 +28,7 @@ Preferences::Preferences(Preferences &&o)
       autostart(o.autostart),
       borderlessMaximized(o.borderlessMaximized),
       contextMenuAlwaysActions(o.contextMenuAlwaysActions),
+      isAvailableGeometryBroadcastedToPlasma(o.isAvailableGeometryBroadcastedToPlasma),
       metaPressForAppLauncher(o.metaPressForAppLauncher),
       metaHoldForBadges(o.metaHoldForBadges),
       mouseSensitivity(o.mouseSensitivity),
@@ -40,6 +42,7 @@ Preferences::Preferences(const Preferences &o)
       autostart(o.autostart),
       borderlessMaximized(o.borderlessMaximized),
       contextMenuAlwaysActions(o.contextMenuAlwaysActions),
+      isAvailableGeometryBroadcastedToPlasma(o.isAvailableGeometryBroadcastedToPlasma),
       metaPressForAppLauncher(o.metaPressForAppLauncher),
       metaHoldForBadges(o.metaHoldForBadges),
       mouseSensitivity(o.mouseSensitivity),
@@ -54,6 +57,7 @@ Preferences &Preferences::operator=(const Preferences &rhs)
     autostart = rhs.autostart;
     borderlessMaximized = rhs.borderlessMaximized;
     contextMenuAlwaysActions = rhs.contextMenuAlwaysActions;
+    isAvailableGeometryBroadcastedToPlasma = rhs.isAvailableGeometryBroadcastedToPlasma;
     metaPressForAppLauncher = rhs.metaPressForAppLauncher;
     metaHoldForBadges = rhs.metaHoldForBadges;
     mouseSensitivity = rhs.mouseSensitivity;
@@ -69,6 +73,7 @@ Preferences &Preferences::operator=(Preferences &&rhs)
     autostart = rhs.autostart;
     borderlessMaximized = rhs.borderlessMaximized;
     contextMenuAlwaysActions = rhs.contextMenuAlwaysActions;
+    isAvailableGeometryBroadcastedToPlasma = rhs.isAvailableGeometryBroadcastedToPlasma;
     metaPressForAppLauncher = rhs.metaPressForAppLauncher;
     metaHoldForBadges = rhs.metaHoldForBadges;
     mouseSensitivity = rhs.mouseSensitivity;
@@ -84,6 +89,7 @@ bool Preferences::operator==(const Preferences &rhs) const
             && (autostart == rhs.autostart)
             && (borderlessMaximized == rhs.borderlessMaximized)
             && (contextMenuAlwaysActions == rhs.contextMenuAlwaysActions)
+            && (isAvailableGeometryBroadcastedToPlasma == rhs.isAvailableGeometryBroadcastedToPlasma)
             && (metaPressForAppLauncher == rhs.metaPressForAppLauncher)
             && (metaHoldForBadges == rhs.metaHoldForBadges)
             && (mouseSensitivity == rhs.mouseSensitivity)
@@ -102,6 +108,7 @@ bool Preferences::inDefaultValues() const
             && (autostart == AUTOSTART)
             && (borderlessMaximized == BORDERLESSMAXIMIZED)
             && (contextMenuAlwaysActions == Data::ContextMenu::ACTIONSALWAYSVISIBLE)
+            && (isAvailableGeometryBroadcastedToPlasma == ISAVAILABLEGEOMETRYBROADCASTEDTOPLASMA)
             && (metaPressForAppLauncher == METAPRESSFORAPPLAUNCHER)
             && (metaHoldForBadges == METAHOLDFORBADGES)
             && (mouseSensitivity == MOUSESENSITIVITY)
@@ -115,6 +122,7 @@ void Preferences::setToDefaults()
     autostart = AUTOSTART;
     borderlessMaximized = BORDERLESSMAXIMIZED;
     contextMenuAlwaysActions = Data::ContextMenu::ACTIONSALWAYSVISIBLE;
+    isAvailableGeometryBroadcastedToPlasma = ISAVAILABLEGEOMETRYBROADCASTEDTOPLASMA;
     metaPressForAppLauncher = METAPRESSFORAPPLAUNCHER;
     metaHoldForBadges = METAHOLDFORBADGES;
     mouseSensitivity = MOUSESENSITIVITY;
