@@ -23,6 +23,7 @@ public:
     static const bool LAYOUTSINFORMATIONWINDOW = true;
     static const bool AUTOSTART = true;
     static const bool BORDERLESSMAXIMIZED = false;
+    static const bool ISAVAILABLEGEOMETRYBROADCASTEDTOPLASMA = true;
     static const bool METAPRESSFORAPPLAUNCHER = false;
     static const bool METAHOLDFORBADGES = true;
     static const int SCREENSDELAY = 2500;
@@ -37,6 +38,7 @@ public:
     bool layoutsInformationWindow{LAYOUTSINFORMATIONWINDOW};
     bool autostart{AUTOSTART};
     bool borderlessMaximized{BORDERLESSMAXIMIZED};
+    bool isAvailableGeometryBroadcastedToPlasma{ISAVAILABLEGEOMETRYBROADCASTEDTOPLASMA};
     bool metaPressForAppLauncher{METAPRESSFORAPPLAUNCHER};
     bool metaHoldForBadges{METAHOLDFORBADGES};
     int screensDelay{SCREENSDELAY};
