@@ -87,6 +87,7 @@ class Corona : public Plasma::Corona
 public:
     Corona(bool defaultLayoutOnStartup = false,
                QString layoutNameOnStartUp = QString(),
+               QString addViewTemplateName = QString(),
                int userSetMemoryUsage = -1,
                QObject *parent = nullptr);
     virtual ~Corona();
@@ -144,6 +145,7 @@ public:
     //! these functions are used from context menu through containmentactions    
     void quitApplication();
     void switchToLayout(QString layout);
+    void importLayoutFile(const QString &filepath, const QString &suggestedLayoutName = QString());
     void showSettingsWindow(int page);
 
     QStringList contextMenuData(const uint &containmentId);
@@ -154,6 +156,8 @@ public slots:
     void activateLauncherMenu();
     void loadDefaultLayout() override;
 
+    void setAutostart(const bool &enabled);
+
     void addView(const uint &containmentId, const QString &templateId);
     void duplicateView(const uint &containmentId);
     void exportViewTemplate(const uint &containmentId);
@@ -219,6 +223,7 @@ private:
     int m_userSetMemoryUsage{ -1};
 
     QString m_layoutNameOnStartUp;
+    QString m_startupAddViewTemplateName;
     QString m_importFullConfigurationFile;
 
     QList<KDeclarative::QmlObjectSharedEngine *> m_alternativesObjects;
