@@ -1,21 +1,8 @@
 /*
-*  Copyright 2017  Smith AR <audoban@openmailbox.org>
-*                  Michail Vourlakos <mvourlakos@gmail.com>
-*
-*  This file is part of Latte-Dock
-*
-*  Latte-Dock is free software; you can redistribute it and/or
-*  modify it under the terms of the GNU General Public License as
-*  published by the Free Software Foundation; either version 2 of
-*  the License, or (at your option) any later version.
-*
-*  Latte-Dock is distributed in the hope that it will be useful,
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*  GNU General Public License for more details.
-*
-*  You should have received a copy of the GNU General Public License
-*  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2017 Smith AR <audoban@openmailbox.org>
+    SPDX-FileCopyrightText: 2017 Michail Vourlakos <mvourlakos@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef CENTRALLAYOUT_H
@@ -24,6 +11,7 @@
 // local
 #include "genericlayout.h"
 #include "../data/layoutdata.h"
+#include "../wm/schemecolors.h"
 
 // Qt
 #include <QObject>
@@ -47,6 +35,7 @@ namespace Latte {
 class CentralLayout : public Layout::GenericLayout
 {
     Q_OBJECT
+    Q_PROPERTY(Latte::WindowSystem::SchemeColors *scheme READ scheme NOTIFY schemeChanged)
 
 public:
     CentralLayout(QObject *parent, QString layoutFile, QString layoutName = QString());
@@ -72,25 +61,34 @@ public:
     Layout::Type type() const override;
     Data::Layout data() const;
 
+    Latte::WindowSystem::SchemeColors *scheme() const;
+
 public:
     Q_INVOKABLE bool isCurrent() override;
 
 signals:
     void disableBordersForMaximizedWindowsChanged();
+    void schemeChanged();
     void showInMenuChanged();
 
 private slots:
     void loadConfig();
     void saveConfig();
 
+    void onSchemeFileChanged();
+
 private:
     void init();
     void importLocalLayout(QString file);
 
+    void setScheme(Latte::WindowSystem::SchemeColors *_scheme);
+
 private:
     bool m_disableBordersForMaximizedWindows{false};
     bool m_showInMenu{false};
     QStringList m_activities;
+
+    Latte::WindowSystem::SchemeColors *m_scheme{nullptr};
 };
 
 }
