@@ -45,16 +45,26 @@ Synchronizer::Synchronizer(QObject *parent)
     connect(this, &Synchronizer::layoutsChanged, this, &Synchronizer::reloadAssignedLayouts);
 
     //! KWin update Disabled Borders
-    connect(this, &Synchronizer::centralLayoutsChanged, this, &Synchronizer::updateKWinDisabledBorders);
+    connect(this, &Synchronizer::centralLayoutsChanged, this, &Synchronizer::updateBorderlessMaximizedAfterTimer);
     connect(m_manager->corona()->universalSettings(), &UniversalSettings::canDisableBordersChanged, this, &Synchronizer::updateKWinDisabledBorders);
 
+    m_updateBorderlessMaximized.setInterval(500);
+    m_updateBorderlessMaximized.setSingleShot(true);
+    connect(&m_updateBorderlessMaximized, &QTimer::timeout, this, &Synchronizer::updateKWinDisabledBorders);
 
     //! KActivities tracking
     connect(m_manager->corona()->activitiesConsumer(), &KActivities::Consumer::activityRemoved,
             this, &Synchronizer::onActivityRemoved);
 
     connect(m_manager->corona()->activitiesConsumer(), &KActivities::Consumer::currentActivityChanged,
-            this, &Synchronizer::onCurrentActivityChanged);
+            this, [&]() {
+        if (m_manager->memoryUsage() == MemoryUsage::MultipleLayouts) {
+            //! this signal is also triggered when runningactivities are changed and actually is received first
+            //! this is why we need a timer here in order to delay that execution and not activate/deactivate
+            //! maximizedborders faulty because syncMultipleLayoutsToActivities(); has not been executed yet
+            updateBorderlessMaximizedAfterTimer();
+        }
+    });
 
     connect(m_manager->corona()->activitiesConsumer(), &KActivities::Consumer::runningActivitiesChanged,
             this, [&]() {
@@ -465,11 +475,12 @@ void Synchronizer::onActivityRemoved(const QString &activityid)
     }
 }
 
-void Synchronizer::onCurrentActivityChanged(const QString &activityid)
+void Synchronizer::updateBorderlessMaximizedAfterTimer()
 {
-    if (m_manager->memoryUsage() == MemoryUsage::MultipleLayouts) {
-        updateKWinDisabledBorders();
-    }
+    //! this signal is also triggered when runningactivities are changed and actually is received first
+    //! this is why we need a timer here in order to delay that execution and not activate/deactivate
+    //! maximizedborders faulty because syncMultipleLayoutsToActivities(); has not been executed yet
+    m_updateBorderlessMaximized.start();
 }
 
 void Synchronizer::hideAllViews()
@@ -653,6 +664,8 @@ bool Synchronizer::initSingleMode(QString layoutName)
         }
 
         m_manager->corona()->universalSettings()->setSingleModeLayoutName(layoutName);
+
+        emit initializationFinished();
     });
 
     return true;
@@ -685,6 +698,8 @@ bool Synchronizer::initMultipleMode(QString layoutName)
         }
 
         syncMultipleLayoutsToActivities();
+
+        emit initializationFinished();
     });
 
     return true;
@@ -902,7 +917,7 @@ void Synchronizer::syncMultipleLayoutsToActivities()
         if (!layoutNamesToLoad.contains(layout->name())) {
             layoutNamesToUnload << layout->name();
         }
-    }    
+    }
 
     QString defaultForcedLayout;
 
@@ -941,7 +956,7 @@ void Synchronizer::syncMultipleLayoutsToActivities()
                                         "Activating layouts: <b>%2</b> ...",
                                         newlyActivatedLayouts.count(),
                                         newlyActivatedLayouts.join(", ")),
-                4000, QStringList(Data::Layout::ALLACTIVITIESID));
+                                  4000, QStringList(Data::Layout::ALLACTIVITIESID));
     }
 
     //! Unload no needed Layouts
