@@ -1,27 +1,15 @@
 /*
-*  Copyright 2016  Smith AR <audoban@openmailbox.org>
-*                  Michail Vourlakos <mvourlakos@gmail.com>
-*
-*  This file is part of Latte-Dock
-*
-*  Latte-Dock is free software; you can redistribute it and/or
-*  modify it under the terms of the GNU General Public License as
-*  published by the Free Software Foundation; either version 2 of
-*  the License, or (at your option) any later version.
-*
-*  Latte-Dock is distributed in the hope that it will be useful,
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*  GNU General Public License for more details.
-*
-*  You should have received a copy of the GNU General Public License
-*  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2016 Smith AR <audoban@openmailbox.org>
+    SPDX-FileCopyrightText: 2016 Michail Vourlakos <mvourlakos@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "lattepackage.h"
 
 // Qt
 #include <QDebug>
+#include <QLatin1String>
 
 // KDE
 #include <KPackage/PackageLoader>
@@ -86,7 +74,7 @@ void Package::pathChanged(KPackage::Package *package)
     if (!pluginName.isEmpty() && pluginName != "org.kde.latte.shell") {
         auto fallback = KPackage::PackageLoader::self()->loadPackage("Plasma/Shell", "org.kde.latte.shell");
         package->setFallbackPackage(fallback);
-    } else if (pluginName.isEmpty() || pluginName == "org.kde.latte.shell") {
+    } else if (pluginName.isEmpty() || pluginName == QLatin1String("org.kde.latte.shell")) {
         package->setFallbackPackage(KPackage::Package());
     }
 }
