@@ -139,15 +139,16 @@ void ScreenGeometries::setPlasmaAvailableScreenRegion(const QString &screenName,
 
     QVariant regionvariant;
 
+    QList<QRect> rects;
     if (!region.isNull()) {
         //! transorm QRegion to QList<QRect> in order to be sent through dbus
-        QList<QRect> rects;
         foreach (const QRect &rect, region) {
             rects << rect;
         }
-
-        regionvariant = QVariant::fromValue(rects);
+    } else {
+        rects << QRect();
     }
+    regionvariant = QVariant::fromValue(rects);
 
     QVariantList args;
 
@@ -189,6 +190,8 @@ void ScreenGeometries::updateGeometries()
 
     qDebug() << " PLASMA SCREEN GEOMETRIES, LAST AVAILABLE SCREEN RECTS :: " << m_lastAvailableRect;
 
+    QStringList clearedScreenNames;
+
     //! check for available geometries changes
     for (QScreen *screen : qGuiApp->screens()) {
         QString scrName = screen->name();
@@ -211,17 +214,23 @@ void ScreenGeometries::updateGeometries()
                                                                                   true,
                                                                                   true);
 
-            //! Disable checks because of the workaround concerning plasma desktop behavior
-            if (!m_lastAvailableRect.contains(scrName) || m_lastAvailableRect[scrName] != availableRect) {
-                m_lastAvailableRect[scrName] = availableRect;
-                setPlasmaAvailableScreenRect(scrName, availableRect);
-                qDebug() << " PLASMA SCREEN GEOMETRIES, AVAILABLE RECT :: " << screen->name() << " : " << availableRect;
-            }
+            bool clearedScreen = (availableRect == screen->geometry());
 
-            if (!m_lastAvailableRegion.contains(scrName) || m_lastAvailableRegion[scrName] != availableRegion) {
-                m_lastAvailableRegion[scrName] = availableRegion;
-                setPlasmaAvailableScreenRegion(scrName, availableRegion);
-                qDebug() << " PLASMA SCREEN GEOMETRIES, AVAILABLE REGION :: " << screen->name() << " : " << availableRegion;
+            if (!clearedScreen) {
+                //! Disable checks because of the workaround concerning plasma desktop behavior
+                if (!m_lastAvailableRect.contains(scrName) || m_lastAvailableRect[scrName] != availableRect) {
+                    m_lastAvailableRect[scrName] = availableRect;
+                    setPlasmaAvailableScreenRect(scrName, availableRect);
+                    qDebug() << " PLASMA SCREEN GEOMETRIES, AVAILABLE RECT :: " << screen->name() << " : " << availableRect;
+                }
+
+                if (!m_lastAvailableRegion.contains(scrName) || m_lastAvailableRegion[scrName] != availableRegion) {
+                    m_lastAvailableRegion[scrName] = availableRegion;
+                    setPlasmaAvailableScreenRegion(scrName, availableRegion);
+                    qDebug() << " PLASMA SCREEN GEOMETRIES, AVAILABLE REGION :: " << screen->name() << " : " << availableRegion;
+                }
+            } else {
+                clearedScreenNames << scrName;
             }
         }
 
@@ -230,14 +239,21 @@ void ScreenGeometries::updateGeometries()
 
     //! check for inactive screens that were published previously
     for (QString &lastScrName : m_lastScreenNames) {
-        if (!screenIsActive(lastScrName)) {
+        bool scractive = screenIsActive(lastScrName);
+
+        if (!scractive || clearedScreenNames.contains(lastScrName)) {
             //! screen became inactive and its geometries could be unpublished
             setPlasmaAvailableScreenRect(lastScrName, QRect());
             setPlasmaAvailableScreenRegion(lastScrName, QRegion());
 
             m_lastAvailableRect.remove(lastScrName);
             m_lastAvailableRegion.remove(lastScrName);
+        }
+
+        if (!scractive) {
             qDebug() << " PLASMA SCREEN GEOMETRIES, INACTIVE SCREEN :: " << lastScrName;
+        } else if (clearedScreenNames.contains(lastScrName)) {
+            qDebug() << " PLASMA SCREEN GEOMETRIES, CLEARED SCREEN :: " << lastScrName;
         }
     }
 
