@@ -67,6 +67,11 @@ void TabPreferences::initUi()
         emit dataChanged();
     });
 
+    connect(m_ui->broadcastGeomChkBox, &QCheckBox::stateChanged, this, [&]() {
+        m_preferences.isAvailableGeometryBroadcastedToPlasma = m_ui->broadcastGeomChkBox->isChecked();
+        emit dataChanged();
+    });
+
     connect(m_ui->screenTrackerSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), [ = ](int i) {
         m_preferences.screensDelay = m_ui->screenTrackerSpinBox->value();
         emit dataChanged();
@@ -100,6 +105,7 @@ void TabPreferences::initSettings()
     o_preferences.autostart = m_corona->universalSettings()->autostart();
     o_preferences.badgeStyle3D = m_corona->universalSettings()->badges3DStyle();
     o_preferences.contextMenuAlwaysActions = m_corona->universalSettings()->contextMenuActionsAlwaysShown();
+    o_preferences.isAvailableGeometryBroadcastedToPlasma = m_corona->universalSettings()->isAvailableGeometryBroadcastedToPlasma();
     o_preferences.layoutsInformationWindow = m_corona->universalSettings()->showInfoWindow();
     o_preferences.metaPressForAppLauncher = m_corona->universalSettings()->kwin_metaForwardedToLatte();
     o_preferences.metaHoldForBadges = m_corona->universalSettings()->metaPressAndHoldEnabled();
@@ -133,6 +139,7 @@ void TabPreferences::updateUi()
     m_ui->autostartChkBox->setChecked(m_preferences.autostart);
     m_ui->badges3DStyleChkBox->setChecked(m_preferences.badgeStyle3D);
     m_ui->infoWindowChkBox->setChecked(m_preferences.layoutsInformationWindow);
+    m_ui->broadcastGeomChkBox->setChecked(m_preferences.isAvailableGeometryBroadcastedToPlasma);
     m_ui->metaPressChkBox->setChecked(m_preferences.metaPressForAppLauncher);
     m_ui->metaPressHoldChkBox->setChecked(m_preferences.metaHoldForBadges);
     m_ui->noBordersForMaximizedChkBox->setChecked(m_preferences.borderlessMaximized);
@@ -184,6 +191,7 @@ void TabPreferences::save()
     m_corona->universalSettings()->setBadges3DStyle(m_preferences.badgeStyle3D);
     m_corona->universalSettings()->setContextMenuActionsAlwaysShown(m_preferences.contextMenuAlwaysActions);
     m_corona->universalSettings()->kwin_forwardMetaToLatte(m_preferences.metaPressForAppLauncher);
+    m_corona->universalSettings()->setIsAvailableGeometryBroadcastedToPlasma(m_preferences.isAvailableGeometryBroadcastedToPlasma);
     m_corona->universalSettings()->setMetaPressAndHoldEnabled(m_preferences.metaHoldForBadges);
     m_corona->universalSettings()->setShowInfoWindow(m_preferences.layoutsInformationWindow);
     m_corona->universalSettings()->setCanDisableBorders(m_preferences.borderlessMaximized);
