@@ -1,20 +1,6 @@
 /*
-*  Copyright 2019  Michail Vourlakos <mvourlakos@gmail.com>
-*
-*  This file is part of Latte-Dock
-*
-*  Latte-Dock is free software; you can redistribute it and/or
-*  modify it under the terms of the GNU General Public License as
-*  published by the Free Software Foundation; either version 2 of
-*  the License, or (at your option) any later version.
-*
-*  Latte-Dock is distributed in the hope that it will be useful,
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*  GNU General Public License for more details.
-*
-*  You should have received a copy of the GNU General Public License
-*  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2019 Michail Vourlakos <mvourlakos@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // local
@@ -25,6 +11,7 @@
 #include <QAction>
 #include <QDir>
 #include <QDebug>
+#include <QLatin1String>
 
 // KDE
 #include <KConfigGroup>
@@ -111,7 +98,7 @@ QString ShortcutsTracker::shortcutToBadge(QStringList shortcutRecords)
             badge = modifiers[modifiers.count() - 1];
 
             //! when shortcut follows Meta+"Character" scheme
-            if (modifiers.count() == 2 && modifiers[0] == "Meta") {
+            if (modifiers.count() == 2 && modifiers[0] == QLatin1String("Meta")) {
                 badge = badge.toLower();
             } else {
                 badge = badge.toUpper();
