@@ -58,6 +58,10 @@ public:
 
     QString proposedTemplateAbsolutePath(QString templateFilename);
 
+    QString viewTemplateFilePath(const QString templateName) const;
+
+    static QString templateName(const QString &filePath);
+
     void importSystemLayouts();
     void installCustomLayoutTemplate(const QString &templateFilePath);
 
