@@ -1,20 +1,6 @@
 /*
-*  Copyright 2018 Michail Vourlakos <mvourlakos@gmail.com>
-*
-*  This file is part of Latte-Dock
-*
-*  Latte-Dock is free software; you can redistribute it and/or
-*  modify it under the terms of the GNU General Public License as
-*  published by the Free Software Foundation; either version 2 of
-*  the License, or (at your option) any later version.
-*
-*  Latte-Dock is distributed in the hope that it will be useful,
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*  GNU General Public License for more details.
-*
-*  You should have received a copy of the GNU General Public License
-*  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2018 Michail Vourlakos <mvourlakos@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "contextmenu.h"
@@ -28,6 +14,7 @@
 // Qt
 #include <QMouseEvent>
 #include <QVersionNumber>
+#include <QLatin1String>
 
 // KDE
 #include <KActionCollection>
@@ -151,7 +138,7 @@ bool ContextMenu::mousePressEventForContainmentMenu(QQuickView *view, QMouseEven
 
     QString trigger = Plasma::ContainmentActions::eventToString(event);
 
-    if (trigger == "RightButton;NoModifier") {
+    if (trigger == QLatin1String("RightButton;NoModifier")) {
         Plasma::ContainmentActions *plugin = m_latteView->containment()->containmentActions().value(trigger);
 
         if (!plugin || plugin->contextualActions().isEmpty()) {
@@ -235,7 +222,7 @@ bool ContextMenu::mousePressEvent(QMouseEvent *event)
     //qDebug() << "1 ...";
     QString trigger = Plasma::ContainmentActions::eventToString(event);
 
-    if (trigger == "RightButton;NoModifier") {
+    if (trigger == QLatin1String("RightButton;NoModifier")) {
         Plasma::ContainmentActions *plugin = m_latteView->containment()->containmentActions().value(trigger);
 
         if (!plugin || plugin->contextualActions().isEmpty()) {
