@@ -564,7 +564,10 @@ void Positioner::immediateSyncGeometry()
                 freeRegion = latteCorona->availableScreenRegionWithCriteria(fixedScreen, activityid, ignoreModes, ignoreEdges);
             }
 
-            maximumRect = maximumNormalGeometry();
+            //! On startup when offscreen use offscreen screen geometry.
+            //! This way vertical docks and panels are not showing are shrinked that
+            //! need to be expanded after sliding-in in startup
+            maximumRect = maximumNormalGeometry(m_inStartup ? availableScreenRect : QRect());
             QRegion availableRegion = freeRegion.intersected(maximumRect);
 
             availableScreenRect = freeRegion.intersected(maximumRect).boundingRect();
@@ -584,7 +587,6 @@ void Positioner::immediateSyncGeometry()
             }
 
             validateTopBottomBorders(availableScreenRect, freeRegion);
-
             m_lastAvailableScreenRegion = freeRegion;
         } else {
             m_view->effects()->setForceTopBorder(false);
@@ -634,23 +636,25 @@ void Positioner::setCanvasGeometry(const QRect &geometry)
 //! this is used mainly from vertical panels in order to
 //! to get the maximum geometry that can be used from the dock
 //! based on their alignment type and the location dock
-QRect Positioner::maximumNormalGeometry()
+QRect Positioner::maximumNormalGeometry(QRect screenGeometry)
 {
+    QRect currentScrGeometry = screenGeometry.isEmpty() ? m_view->screen()->geometry() : screenGeometry;
+
     int xPos = 0;
-    int yPos = m_view->screen()->geometry().y();;
-    int maxHeight = m_view->screen()->geometry().height();
+    int yPos = currentScrGeometry.y();;
+    int maxHeight = currentScrGeometry.height();
     int maxWidth = m_view->maxNormalThickness();
     QRect maxGeometry;
     maxGeometry.setRect(0, 0, maxWidth, maxHeight);
 
     switch (m_view->location()) {
     case Plasma::Types::LeftEdge:
-        xPos = m_view->screen()->geometry().x();
+        xPos = currentScrGeometry.x();
         maxGeometry.setRect(xPos, yPos, maxWidth, maxHeight);
         break;
 
     case Plasma::Types::RightEdge:
-        xPos = m_view->screen()->geometry().right() - maxWidth + 1;
+        xPos = currentScrGeometry.right() - maxWidth + 1;
         maxGeometry.setRect(xPos, yPos, maxWidth, maxHeight);
         break;
 
@@ -669,7 +673,8 @@ void Positioner::validateTopBottomBorders(QRect availableScreenRect, QRegion ava
 
     if (availableScreenRect.top() != m_view->screenGeometry().top()) {
         //! check top border
-        QRegion fitInRegion = QRect(m_view->screenGeometry().x(), availableScreenRect.y()-1, edgeMargin, 1);
+        int x = m_view->location() == Plasma::Types::LeftEdge ? m_view->screenGeometry().x() : m_view->screenGeometry().right() - edgeMargin + 1;
+        QRegion fitInRegion = QRect(x, availableScreenRect.y()-1, edgeMargin, 1);
         QRegion subtracted = fitInRegion.subtracted(availableScreenRegion);
 
         if (subtracted.isNull()) {
@@ -685,7 +690,8 @@ void Positioner::validateTopBottomBorders(QRect availableScreenRect, QRegion ava
 
     if (availableScreenRect.bottom() != m_view->screenGeometry().bottom()) {
         //! check top border
-        QRegion fitInRegion = QRect(m_view->screenGeometry().x(), availableScreenRect.bottom()+1, edgeMargin, 1);
+        int x = m_view->location() == Plasma::Types::LeftEdge ? m_view->screenGeometry().x() : m_view->screenGeometry().right()  - edgeMargin + 1;
+        QRegion fitInRegion = QRect(x, availableScreenRect.bottom()+1, edgeMargin, 1);
         QRegion subtracted = fitInRegion.subtracted(availableScreenRegion);
 
         if (subtracted.isNull()) {
@@ -966,10 +972,16 @@ void Positioner::initSignalingForLocationChangeSliding()
 
     //! SCREEN
     connect(m_view, &QQuickView::screenChanged, this, [&]() {
+        if (!m_view || !m_nextScreen) {
+            return;
+        }
+        //if panels are not excluded from confirmed geometry check then they are stuck in sliding out end
+        //and they do not switch to new screen geometry
+        bool confirmedgeometry = m_view->behaveAsPlasmaPanel() || (!m_view->behaveAsPlasmaPanel() && m_nextScreen->geometry().contains(m_view->geometry().center()));
+
         if (m_nextScreen
                 && m_nextScreen == m_view->screen()
-                && m_nextScreen->geometry().contains(m_view->geometry().center())) {
-
+                && confirmedgeometry) {
             bool isrelocationlastevent = isLastHidingRelocationEvent();
             m_nextScreen = nullptr;
             m_nextScreenName = "";
