@@ -1,21 +1,8 @@
 /*
-*  Copyright 2016  Smith AR <audoban@openmailbox.org>
-*                  Michail Vourlakos <mvourlakos@gmail.com>
-*
-*  This file is part of Latte-Dock
-*
-*  Latte-Dock is free software; you can redistribute it and/or
-*  modify it under the terms of the GNU General Public License as
-*  published by the Free Software Foundation; either version 2 of
-*  the License, or (at your option) any later version.
-*
-*  Latte-Dock is distributed in the hope that it will be useful,
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*  GNU General Public License for more details.
-*
-*  You should have received a copy of the GNU General Public License
-*  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2016 Smith AR <audoban@openmailbox.org>
+    SPDX-FileCopyrightText: 2016 Michail Vourlakos <mvourlakos@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "primaryconfigview.h"
@@ -133,14 +120,14 @@ Config::IndicatorUiManager *PrimaryConfigView::indicatorUiManager()
 
 void PrimaryConfigView::setOnActivities(QStringList activities)
 {
-    m_corona->wm()->setWindowOnActivities(*this, activities);
+    m_corona->wm()->setWindowOnActivities(trackedWindowId(), activities);
 
     if (m_secConfigView) {
-        m_corona->wm()->setWindowOnActivities(*m_secConfigView.data(), activities);
+        m_corona->wm()->setWindowOnActivities(m_secConfigView->trackedWindowId(), activities);
     }
 
     if (m_canvasConfigView) {
-        m_corona->wm()->setWindowOnActivities(*m_canvasConfigView.data(), activities);
+        m_corona->wm()->setWindowOnActivities(m_canvasConfigView->trackedWindowId(), activities);
     }
 }
 
