@@ -62,6 +62,8 @@ AbstractWindowInterface::AbstractWindowInterface(QObject *parent)
         emit currentActivityChanged();
     });
 
+    connect(KWindowSystem::self(), &KWindowSystem::showingDesktopChanged, this, &AbstractWindowInterface::setIsShowingDesktop);
+
     //! KWin Service tracking
     m_kwinServiceWatcher->setConnection(QDBusConnection::sessionBus());
     m_kwinServiceWatcher->setWatchedServices(QStringList({KWINSERVICE}));
@@ -88,6 +90,21 @@ AbstractWindowInterface::~AbstractWindowInterface()
     m_windowsTracker->deleteLater();
 }
 
+bool AbstractWindowInterface::isShowingDesktop() const
+{
+    return m_isShowingDesktop;
+}
+
+void AbstractWindowInterface::setIsShowingDesktop(const bool &showing)
+{
+    if (m_isShowingDesktop == showing) {
+        return;
+    }
+
+    m_isShowingDesktop = showing;
+    emit isShowingDesktopChanged();
+}
+
 QString AbstractWindowInterface::currentDesktop()
 {
     return m_currentDesktop;
@@ -244,6 +261,11 @@ bool AbstractWindowInterface::inCurrentDesktopActivity(const WindowInfoWrap &win
 }
 
 //! KWin Interface
+bool AbstractWindowInterface::isKWinRunning() const
+{
+    return m_isKWinInterfaceAvailable;
+}
+
 void AbstractWindowInterface::initKWinInterface()
 {
     QDBusInterface kwinIface(KWINSERVICE, "/VirtualDesktopManager", KWINVIRTUALDESKTOPMANAGERNAMESPACE, QDBusConnection::sessionBus());
